@@ -100,9 +100,9 @@ kSlideShowSaver::kSlideShowSaver( WId id ): KScreenSaver(id)
   mEffect = NULL;
   mNumEffects = 0;
   mIntArray = NULL;
+  readConfig();
   registerEffects();
 
-  readConfig();
   initNextScreen();
 
   mFileIdx = 0;
@@ -159,10 +159,12 @@ void kSlideShowSaver::readConfig()
   mShowRandom = config.readEntry("ShowRandom", true);
   mZoomImages = config.readEntry("ZoomImages", false);
   mPrintName = config.readEntry("PrintName", true);
+  mPrintPath = config.readEntry("PrintPath", false);
   mDirectory = config.readPathEntry("Directory", KGlobal::dirs()->findDirs("wallpaper", QLatin1String( "" )).last());
   mDelay = config.readEntry("Delay", 10) * 1000;
   mSubdirectory = config.readEntry("SubDirectory", false);
   mRandomPosition = config.readEntry("RandomPosition", false);
+  mEffectsEnabled = config.readEntry("EffectsEnabled", true);
 
   loadDirectory();
 }
@@ -171,6 +173,12 @@ void kSlideShowSaver::readConfig()
 //----------------------------------------------------------------------------
 void kSlideShowSaver::registerEffects()
 {
+  if (!mEffectsEnabled)
+  {
+    mEffectList = 0;
+    return;
+  }
+
   int i = 0;
 
   mEffectList = new EffectMethod[64];
@@ -721,13 +729,20 @@ void kSlideShowSaver::paintEvent(QPaintEvent *)
   {
     loadNextImage();
     createNextScreen();
+    if (mNumEffects == 0)
+    {
+      showNextScreen();
+      tmout = -1;
+    }
+    else
+    {
+      if (mNumEffects > 1) i = KRandom::random() % mNumEffects;
+      else i = 0;
 
-    if (mNumEffects > 1) i = KRandom::random() % mNumEffects;
-    else i = 0;
-
-    mEffect = mEffectList[i];
-    mEffectRunning = true;
-    tmout = (this->*mEffect)(true);
+      mEffect = mEffectList[i];
+      mEffectRunning = true;
+      tmout = (this->*mEffect)(true);
+    }
   }
   if (tmout <= 0)
   {
@@ -887,7 +902,7 @@ nexttry:
   exiv.rotateExifQImage(mImage, exiv.getImageOrientation());
 #endif
 
-  mImageName = QFileInfo(fname).baseName();
+  mImageName = mPrintPath ? fname : QFileInfo(fname).baseName();
 }
 
 
@@ -977,11 +992,13 @@ void kSlideShowSetup::readSettings()
     cfg->mCbxRandom->setChecked(config.readEntry("ShowRandom", true));
     cfg->mCbxZoom->setChecked(config.readEntry("ZoomImages", false));
     cfg->mCbxShowName->setChecked(config.readEntry("PrintName", true));
+    cfg->mCbxShowPath->setChecked(config.readEntry("PrintPath", false));
     cfg->mDelay->setValue(config.readEntry("Delay", 20));
     cfg->mDelay->setSuffix(ki18np(" second", " seconds"));
     cfg->mDirChooser->setUrl(KUrl(config.readPathEntry("Directory", QString())));
     cfg->mCbxSubdirectory->setChecked(config.readEntry("SubDirectory", false));
     cfg->mCbxRandomPosition->setChecked(config.readEntry("RandomPosition", false));
+    //cfg->mCbxEffectsEnabled->setChecked(config.readEntry("EffectsEnabled", true));
 }
 
 
@@ -993,10 +1010,12 @@ void kSlideShowSetup::writeSettings()
   config.writeEntry("ShowRandom", cfg->mCbxRandom->isChecked());
   config.writeEntry("ZoomImages", cfg->mCbxZoom->isChecked());
   config.writeEntry("PrintName",  cfg->mCbxShowName->isChecked());
+  config.writeEntry("PrintPath",  cfg->mCbxShowPath->isChecked());
   config.writeEntry("Delay", cfg->mDelay->value());
   config.writePathEntry("Directory", cfg->mDirChooser->url().path());
   config.writeEntry("SubDirectory", cfg->mCbxSubdirectory->isChecked());
   config.writeEntry("RandomPosition", cfg->mCbxRandomPosition->isChecked());
+  //config.writeEntry("EffectsEnabled", cfg->mCbxEffectsEnabled->isChecked());
 
   config.sync();
 
